@@ -16,3 +16,12 @@ class AthenaClientError(JsonRESTError):
                 "RequestId": "6876f774-7273-11e4-85dc-39e55ca848d1",
             }
         )
+
+
+class InvalidArgumentException(JsonRESTError):
+    """The specified input parameter has a value that is not valid."""
+
+    code = 400
+
+    def __init__(self, message: str):
+        super().__init__("InvalidArgumentException", message)
