@@ -1,10 +1,12 @@
 import json
+import re
 import sys
 from typing import Any, Dict, List, Tuple, Union
 from urllib.parse import unquote
 
 from moto.core.responses import TYPE_RESPONSE, BaseResponse
 from moto.utilities.aws_headers import amz_crc32
+from moto.utilities.utils import ARN_PARTITION_REGEX
 
 from .exceptions import FunctionAlreadyExists, UnknownFunctionException
 from .models import LambdaBackend
@@ -89,7 +91,8 @@ class LambdaResponse(BaseResponse):
     def invoke_async(self) -> Tuple[int, Dict[str, str], Union[str, bytes]]:
         response_headers: Dict[str, Any] = {}
 
-        function_name = unquote(self.path.rsplit("/", 3)[-3])
+        function_index = -3 if self.path.endswith("/") else -2
+        function_name = unquote(self.path.rsplit("/", 3)[function_index])
 
         fn = self.backend.get_function(function_name, None)
         payload = fn.invoke(self.body, self.headers, response_headers)
@@ -224,7 +227,7 @@ class LambdaResponse(BaseResponse):
         configuration: Dict[str, Any], function_name: str, qualifier: str
     ) -> Dict[str, Any]:
         # Qualifier may be explicitly passed or part of function name or ARN, extract it here
-        if function_name.startswith("arn:aws"):
+        if re.match(ARN_PARTITION_REGEX, function_name):
             # Extract from ARN
             if ":" in function_name.split(":function:")[-1]:
                 qualifier = function_name.split(":")[-1]
@@ -319,20 +322,14 @@ class LambdaResponse(BaseResponse):
 
     def get_function_concurrency(self) -> TYPE_RESPONSE:
         path_function_name = unquote(self.path.rsplit("/", 2)[-2])
-        function_name = self.backend.get_function(path_function_name)
-
-        if function_name is None:
-            return 404, {"status": 404}, "{}"
+        self.backend.get_function(path_function_name)
 
         resp = self.backend.get_function_concurrency(path_function_name)
         return 200, {}, json.dumps({"ReservedConcurrentExecutions": resp})
 
     def delete_function_concurrency(self) -> TYPE_RESPONSE:
         path_function_name = unquote(self.path.rsplit("/", 2)[-2])
-        function_name = self.backend.get_function(path_function_name)
-
-        if function_name is None:
-            return 404, {}, "{}"
+        self.backend.get_function(path_function_name)
 
         self.backend.delete_function_concurrency(path_function_name)
 
@@ -340,10 +337,7 @@ class LambdaResponse(BaseResponse):
 
     def put_function_concurrency(self) -> TYPE_RESPONSE:
         path_function_name = unquote(self.path.rsplit("/", 2)[-2])
-        function = self.backend.get_function(path_function_name)
-
-        if function is None:
-            return 404, {}, "{}"
+        self.backend.get_function(path_function_name)
 
         concurrency = self._get_param("ReservedConcurrentExecutions", None)
         resp = self.backend.put_function_concurrency(path_function_name, concurrency)
@@ -454,3 +448,34 @@ class LambdaResponse(BaseResponse):
         return json.dumps(
             self.backend.list_function_event_invoke_configs(function_name)
         )
+
+    def add_layer_version_permission(self) -> str:
+        statement = self.body
+        layer_name = self._get_param("LayerName")
+        version_number = self._get_param("VersionNumber")
+        statement, revision_id = self.backend.add_layer_version_permission(
+            layer_name=layer_name,
+            version_number=version_number,
+            statement=statement,
+        )
+        return json.dumps(dict(Statement=json.dumps(statement), RevisionId=revision_id))
+
+    def get_layer_version_policy(self) -> str:
+        layer_name = self._get_param("LayerName")
+        version_number = self._get_param("VersionNumber")
+        return self.backend.get_layer_version_policy(
+            layer_name=layer_name, version_number=version_number
+        )
+
+    def remove_layer_version_permission(self) -> TYPE_RESPONSE:
+        layer_name = self._get_param("LayerName")
+        version_number = self._get_param("VersionNumber")
+        statement_id = self.path.split("/")[-1].split("?")[0]
+        revision = self.querystring.get("RevisionId", "")
+        if self.backend.get_layer_version(layer_name, version_number):
+            self.backend.remove_layer_version_permission(
+                layer_name, version_number, statement_id, revision
+            )
+            return 204, {"status": 204}, "{}"
+        else:
+            return 404, {"status": 404}, "{}"
