@@ -1,93 +1,99 @@
-from moto.core.responses import BaseResponse
-from moto.ec2.utils import filters_from_querystring, add_tag_specification
+from moto.ec2.utils import add_tag_specification
+
+from ._base_response import EC2BaseResponse
 
 
-class TransitGatewayAttachment(BaseResponse):
-    def create_transit_gateway_vpc_attachment(self):
+class TransitGatewayAttachment(EC2BaseResponse):
+    def create_transit_gateway_vpc_attachment(self) -> str:
         options = self._get_multi_param_dict("Options")
         subnet_ids = self._get_multi_param("SubnetIds")
         transit_gateway_id = self._get_param("TransitGatewayId")
         vpc_id = self._get_param("VpcId")
 
-        tags = self._get_multi_param("TagSpecifications")
-        tags = tags[0] if isinstance(tags, list) and len(tags) == 1 else tags
-        tags = (tags or {}).get("Tag", [])
-        tags = {t["Key"]: t["Value"] for t in tags}
+        tags = self._parse_tag_specification().get("transit-gateway-route-table", {})
 
-        transit_gateway_attachment = self.ec2_backend.create_transit_gateway_vpc_attachment(
-            transit_gateway_id=transit_gateway_id,
-            tags=tags,
-            vpc_id=vpc_id,
-            subnet_ids=subnet_ids,
-            options=options,
+        transit_gateway_attachment = (
+            self.ec2_backend.create_transit_gateway_vpc_attachment(
+                transit_gateway_id=transit_gateway_id,
+                tags=tags,
+                vpc_id=vpc_id,
+                subnet_ids=subnet_ids,
+                options=options,
+            )
         )
         template = self.response_template(CREATE_TRANSIT_GATEWAY_VPC_ATTACHMENT)
         return template.render(transit_gateway_attachment=transit_gateway_attachment)
 
-    def describe_transit_gateway_vpc_attachments(self):
+    def describe_transit_gateway_vpc_attachments(self) -> str:
         transit_gateways_attachment_ids = self._get_multi_param(
             "TransitGatewayAttachmentIds"
         )
-        filters = filters_from_querystring(self.querystring)
-        max_results = self._get_param("MaxResults")
-        transit_gateway_vpc_attachments = self.ec2_backend.describe_transit_gateway_vpc_attachments(
-            transit_gateways_attachment_ids=transit_gateways_attachment_ids,
-            filters=filters,
-            max_results=max_results,
+        filters = self._filters_from_querystring()
+        transit_gateway_vpc_attachments = (
+            self.ec2_backend.describe_transit_gateway_vpc_attachments(
+                transit_gateways_attachment_ids=transit_gateways_attachment_ids,
+                filters=filters,
+            )
         )
         template = self.response_template(DESCRIBE_TRANSIT_GATEWAY_VPC_ATTACHMENTS)
         return template.render(
             transit_gateway_vpc_attachments=transit_gateway_vpc_attachments
         )
 
-    def modify_transit_gateway_vpc_attachment(self):
+    def modify_transit_gateway_vpc_attachment(self) -> str:
         add_subnet_ids = self._get_multi_param("AddSubnetIds")
         options = self._get_multi_param_dict("Options")
         remove_subnet_ids = self._get_multi_param("RemoveSubnetIds")
         transit_gateway_attachment_id = self._get_param("TransitGatewayAttachmentId")
 
-        transit_gateway_attachment = self.ec2_backend.modify_transit_gateway_vpc_attachment(
-            add_subnet_ids=add_subnet_ids,
-            options=options,
-            remove_subnet_ids=remove_subnet_ids,
-            transit_gateway_attachment_id=transit_gateway_attachment_id,
+        transit_gateway_attachment = (
+            self.ec2_backend.modify_transit_gateway_vpc_attachment(
+                add_subnet_ids=add_subnet_ids,
+                options=options,
+                remove_subnet_ids=remove_subnet_ids,
+                transit_gateway_attachment_id=transit_gateway_attachment_id,
+            )
         )
         template = self.response_template(MODIFY_TRANSIT_GATEWAY_VPC_ATTACHMENTS)
         return template.render(transit_gateway_attachment=transit_gateway_attachment)
 
-    def describe_transit_gateway_attachments(self):
+    def describe_transit_gateway_attachments(self) -> str:
         transit_gateways_attachment_ids = self._get_multi_param(
             "TransitGatewayAttachmentIds"
         )
-        filters = filters_from_querystring(self.querystring)
-        max_results = self._get_param("MaxResults")
-        transit_gateway_attachments = self.ec2_backend.describe_transit_gateway_attachments(
-            transit_gateways_attachment_ids=transit_gateways_attachment_ids,
-            filters=filters,
-            max_results=max_results,
+        filters = self._filters_from_querystring()
+        transit_gateway_attachments = (
+            self.ec2_backend.describe_transit_gateway_attachments(
+                transit_gateways_attachment_ids=transit_gateways_attachment_ids,
+                filters=filters,
+            )
         )
         template = self.response_template(DESCRIBE_TRANSIT_GATEWAY_ATTACHMENTS)
         return template.render(transit_gateway_attachments=transit_gateway_attachments)
 
-    def delete_transit_gateway_vpc_attachment(self):
+    def delete_transit_gateway_vpc_attachment(self) -> str:
         transit_gateway_attachment_id = self._get_param("TransitGatewayAttachmentId")
-        transit_gateway_attachment = self.ec2_backend.delete_transit_gateway_vpc_attachment(
-            transit_gateway_attachment_id=transit_gateway_attachment_id
+        transit_gateway_attachment = (
+            self.ec2_backend.delete_transit_gateway_vpc_attachment(
+                transit_gateway_attachment_id=transit_gateway_attachment_id
+            )
         )
         template = self.response_template(DELETE_TRANSIT_GATEWAY_VPC_ATTACHMENTS)
         return template.render(transit_gateway_attachment=transit_gateway_attachment)
 
-    def associate_transit_gateway_route_table(self):
+    def associate_transit_gateway_route_table(self) -> str:
         transit_gateway_attachment_id = self._get_param("TransitGatewayAttachmentId")
         transit_gateway_route_table_id = self._get_param("TransitGatewayRouteTableId")
-        transit_gateway_association = self.ec2_backend.associate_transit_gateway_route_table(
-            transit_gateway_attachment_id=transit_gateway_attachment_id,
-            transit_gateway_route_table_id=transit_gateway_route_table_id,
+        transit_gateway_association = (
+            self.ec2_backend.associate_transit_gateway_route_table(
+                transit_gateway_attachment_id=transit_gateway_attachment_id,
+                transit_gateway_route_table_id=transit_gateway_route_table_id,
+            )
         )
         template = self.response_template(TRANSIT_GATEWAY_ASSOCIATION)
         return template.render(transit_gateway_association=transit_gateway_association)
 
-    def disassociate_transit_gateway_route_table(self,):
+    def disassociate_transit_gateway_route_table(self) -> str:
         tgw_attach_id = self._get_param("TransitGatewayAttachmentId")
         tgw_rt_id = self._get_param("TransitGatewayRouteTableId")
 
@@ -97,38 +103,44 @@ class TransitGatewayAttachment(BaseResponse):
         template = self.response_template(TRANSIT_GATEWAY_DISASSOCIATION)
         return template.render(tgw_association=tgw_association)
 
-    def enable_transit_gateway_route_table_propagation(self):
+    def enable_transit_gateway_route_table_propagation(self) -> str:
         transit_gateway_attachment_id = self._get_param("TransitGatewayAttachmentId")
         transit_gateway_route_table_id = self._get_param("TransitGatewayRouteTableId")
-        transit_gateway_propagation = self.ec2_backend.enable_transit_gateway_route_table_propagation(
-            transit_gateway_attachment_id=transit_gateway_attachment_id,
-            transit_gateway_route_table_id=transit_gateway_route_table_id,
+        transit_gateway_propagation = (
+            self.ec2_backend.enable_transit_gateway_route_table_propagation(
+                transit_gateway_attachment_id=transit_gateway_attachment_id,
+                transit_gateway_route_table_id=transit_gateway_route_table_id,
+            )
         )
         template = self.response_template(TRANSIT_GATEWAY_PROPAGATION)
         return template.render(transit_gateway_propagation=transit_gateway_propagation)
 
-    def disable_transit_gateway_route_table_propagation(self):
+    def disable_transit_gateway_route_table_propagation(self) -> str:
         transit_gateway_attachment_id = self._get_param("TransitGatewayAttachmentId")
         transit_gateway_route_table_id = self._get_param("TransitGatewayRouteTableId")
-        transit_gateway_propagation = self.ec2_backend.disable_transit_gateway_route_table_propagation(
-            transit_gateway_attachment_id=transit_gateway_attachment_id,
-            transit_gateway_route_table_id=transit_gateway_route_table_id,
+        transit_gateway_propagation = (
+            self.ec2_backend.disable_transit_gateway_route_table_propagation(
+                transit_gateway_attachment_id=transit_gateway_attachment_id,
+                transit_gateway_route_table_id=transit_gateway_route_table_id,
+            )
         )
         template = self.response_template(TRANSIT_GATEWAY_PROPAGATION)
         return template.render(transit_gateway_propagation=transit_gateway_propagation)
 
-    def create_transit_gateway_peering_attachment(self):
+    def create_transit_gateway_peering_attachment(self) -> str:
         peer_account_id = self._get_param("PeerAccountId")
         peer_region = self._get_param("PeerRegion")
         peer_transit_gateway_id = self._get_param("PeerTransitGatewayId")
         transit_gateway_id = self._get_param("TransitGatewayId")
         tags = add_tag_specification(self._get_multi_param("TagSpecification"))
-        transit_gateway_peering_attachment = self.ec2_backend.create_transit_gateway_peering_attachment(
-            transit_gateway_id,
-            peer_transit_gateway_id,
-            peer_region,
-            peer_account_id,
-            tags,
+        transit_gateway_peering_attachment = (
+            self.ec2_backend.create_transit_gateway_peering_attachment(
+                transit_gateway_id,
+                peer_transit_gateway_id,
+                peer_region,
+                peer_account_id,
+                tags,
+            )
         )
         template = self.response_template(TRANSIT_GATEWAY_PEERING_ATTACHMENT)
         return template.render(
@@ -136,26 +148,28 @@ class TransitGatewayAttachment(BaseResponse):
             transit_gateway_peering_attachment=transit_gateway_peering_attachment,
         )
 
-    def describe_transit_gateway_peering_attachments(self):
+    def describe_transit_gateway_peering_attachments(self) -> str:
         transit_gateways_attachment_ids = self._get_multi_param(
             "TransitGatewayAttachmentIds"
         )
-        filters = filters_from_querystring(self.querystring)
-        max_results = self._get_param("MaxResults")
-        transit_gateway_peering_attachments = self.ec2_backend.describe_transit_gateway_peering_attachments(
-            transit_gateways_attachment_ids=transit_gateways_attachment_ids,
-            filters=filters,
-            max_results=max_results,
+        filters = self._filters_from_querystring()
+        transit_gateway_peering_attachments = (
+            self.ec2_backend.describe_transit_gateway_peering_attachments(
+                transit_gateways_attachment_ids=transit_gateways_attachment_ids,
+                filters=filters,
+            )
         )
         template = self.response_template(DESCRIBE_TRANSIT_GATEWAY_PEERING_ATTACHMENTS)
         return template.render(
             transit_gateway_peering_attachments=transit_gateway_peering_attachments
         )
 
-    def accept_transit_gateway_peering_attachment(self):
+    def accept_transit_gateway_peering_attachment(self) -> str:
         transit_gateway_attachment_id = self._get_param("TransitGatewayAttachmentId")
-        transit_gateway_peering_attachment = self.ec2_backend.accept_transit_gateway_peering_attachment(
-            transit_gateway_attachment_id=transit_gateway_attachment_id
+        transit_gateway_peering_attachment = (
+            self.ec2_backend.accept_transit_gateway_peering_attachment(
+                transit_gateway_attachment_id=transit_gateway_attachment_id
+            )
         )
         template = self.response_template(TRANSIT_GATEWAY_PEERING_ATTACHMENT)
         return template.render(
@@ -163,10 +177,12 @@ class TransitGatewayAttachment(BaseResponse):
             transit_gateway_peering_attachment=transit_gateway_peering_attachment,
         )
 
-    def delete_transit_gateway_peering_attachment(self):
+    def delete_transit_gateway_peering_attachment(self) -> str:
         transit_gateway_attachment_id = self._get_param("TransitGatewayAttachmentId")
-        transit_gateway_peering_attachment = self.ec2_backend.delete_transit_gateway_peering_attachment(
-            transit_gateway_attachment_id=transit_gateway_attachment_id
+        transit_gateway_peering_attachment = (
+            self.ec2_backend.delete_transit_gateway_peering_attachment(
+                transit_gateway_attachment_id=transit_gateway_attachment_id
+            )
         )
         template = self.response_template(TRANSIT_GATEWAY_PEERING_ATTACHMENT)
         return template.render(
@@ -174,10 +190,12 @@ class TransitGatewayAttachment(BaseResponse):
             transit_gateway_peering_attachment=transit_gateway_peering_attachment,
         )
 
-    def reject_transit_gateway_peering_attachment(self):
+    def reject_transit_gateway_peering_attachment(self) -> str:
         transit_gateway_attachment_id = self._get_param("TransitGatewayAttachmentId")
-        transit_gateway_peering_attachment = self.ec2_backend.reject_transit_gateway_peering_attachment(
-            transit_gateway_attachment_id=transit_gateway_attachment_id
+        transit_gateway_peering_attachment = (
+            self.ec2_backend.reject_transit_gateway_peering_attachment(
+                transit_gateway_attachment_id=transit_gateway_attachment_id
+            )
         )
         template = self.response_template(TRANSIT_GATEWAY_PEERING_ATTACHMENT)
         return template.render(
@@ -189,11 +207,12 @@ class TransitGatewayAttachment(BaseResponse):
 CREATE_TRANSIT_GATEWAY_VPC_ATTACHMENT = """<CreateTransitGatewayVpcAttachmentResponse xmlns="http://ec2.amazonaws.com/doc/2016-11-15/">
         <requestId>9b5766ac-2af6-4b92-9a8a-4d74ae46ae79</requestId>
         <transitGatewayVpcAttachment>
-            <createTime>{{ transit_gateway_attachment.create_time }}</createTime>
+            <creationTime>{{ transit_gateway_attachment.create_time }}</creationTime>
             <options>
                 <applianceModeSupport>{{ transit_gateway_attachment.options.ApplianceModeSupport }}</applianceModeSupport>
                 <dnsSupport>{{ transit_gateway_attachment.options.DnsSupport }}</dnsSupport>
                 <ipv6Support>{{ transit_gateway_attachment.options.Ipv6Support }}</ipv6Support>
+                <securityGroupReferencingSupport>enable</securityGroupReferencingSupport>
             </options>
             <state>{{ transit_gateway_attachment.state }}</state>
             <subnetIds>
@@ -201,6 +220,7 @@ CREATE_TRANSIT_GATEWAY_VPC_ATTACHMENT = """<CreateTransitGatewayVpcAttachmentRes
                 <item>{{ subnet_id }}</item>
             {% endfor %}
             </subnetIds>
+            {% if transit_gateway_attachment.get_tags() %}
             <tagSet>
             {% for tag in transit_gateway_attachment.get_tags() %}
                 <item>
@@ -209,6 +229,7 @@ CREATE_TRANSIT_GATEWAY_VPC_ATTACHMENT = """<CreateTransitGatewayVpcAttachmentRes
                 </item>
             {% endfor %}
             </tagSet>
+            {% endif %}
             <transitGatewayAttachmentId>{{ transit_gateway_attachment.id }}</transitGatewayAttachmentId>
             <transitGatewayId>{{ transit_gateway_attachment.transit_gateway_id }}</transitGatewayId>
             <vpcId>{{ transit_gateway_attachment.vpc_id }}</vpcId>
@@ -231,6 +252,7 @@ DESCRIBE_TRANSIT_GATEWAY_ATTACHMENTS = """<DescribeTransitGatewayAttachmentsResp
             <resourceOwnerId>{{ transit_gateway_attachment.resource_owner_id }}</resourceOwnerId>
             <resourceType>{{ transit_gateway_attachment.resource_type }}</resourceType>
             <state>{{ transit_gateway_attachment.state }}</state>
+            {% if transit_gateway_attachment.get_tags() %}
             <tagSet>
             {% for tag in transit_gateway_attachment.get_tags() %}
                 <item>
@@ -239,6 +261,7 @@ DESCRIBE_TRANSIT_GATEWAY_ATTACHMENTS = """<DescribeTransitGatewayAttachmentsResp
                 </item>
             {% endfor %}
             </tagSet>
+            {% endif %}
             <transitGatewayAttachmentId>{{ transit_gateway_attachment.id }}</transitGatewayAttachmentId>
             <transitGatewayId>{{ transit_gateway_attachment.transit_gateway_id }}</transitGatewayId>
             <transitGatewayOwnerId>{{ transit_gateway_attachment.resource_owner_id }}</transitGatewayOwnerId>
@@ -254,12 +277,13 @@ DESCRIBE_TRANSIT_GATEWAY_VPC_ATTACHMENTS = """<DescribeTransitGatewayVpcAttachme
         <transitGatewayVpcAttachments>
         {% for transit_gateway_vpc_attachment in transit_gateway_vpc_attachments %}
             <item>
-                <creationTime>2021-07-18T08:57:21.000Z</creationTime>
+                <creationTime>{{ transit_gateway_vpc_attachment.create_time }}</creationTime>
                 {% if transit_gateway_vpc_attachment.options %}
                 <options>
                     <applianceModeSupport>{{ transit_gateway_vpc_attachment.options.ApplianceModeSupport }}</applianceModeSupport>
                     <dnsSupport>{{ transit_gateway_vpc_attachment.options.DnsSupport }}</dnsSupport>
                     <ipv6Support>{{ transit_gateway_vpc_attachment.options.Ipv6Support }}</ipv6Support>
+                    <securityGroupReferencingSupport>enable</securityGroupReferencingSupport>
                 </options>
                 {% endif %}
                 <state>{{ transit_gateway_vpc_attachment.state }}</state>
@@ -268,6 +292,7 @@ DESCRIBE_TRANSIT_GATEWAY_VPC_ATTACHMENTS = """<DescribeTransitGatewayVpcAttachme
                     <item>{{ id }}</item>
                 {% endfor %}
                 </subnetIds>
+                {% if transit_gateway_vpc_attachment.get_tags() %}
                 <tagSet>
                 {% for tag in transit_gateway_vpc_attachment.get_tags() %}
                     <item>
@@ -276,6 +301,7 @@ DESCRIBE_TRANSIT_GATEWAY_VPC_ATTACHMENTS = """<DescribeTransitGatewayVpcAttachme
                     </item>
                 {% endfor %}
                 </tagSet>
+                {% endif %}
                 <transitGatewayAttachmentId>{{ transit_gateway_vpc_attachment.id }}</transitGatewayAttachmentId>
                 <transitGatewayId>{{ transit_gateway_vpc_attachment.transit_gateway_id }}</transitGatewayId>
                 <vpcId>{{ transit_gateway_vpc_attachment.vpc_id }}</vpcId>
