@@ -1,20 +1,20 @@
 from __future__ import annotations
 
 from datetime import datetime, timedelta
+from functools import cache, cached_property
 from typing import Any, Dict, List, Optional, Tuple
 
-from dateutil.parser import parse as dtparse
-
 from moto.core.base_backend import BackendDict, BaseBackend
 from moto.core.common_models import BaseModel, CloudFormationModel
 from moto.core.utils import utcnow
 from moto.ec2.models.instances import Instance as EC2Instance
 from moto.emr.exceptions import (
+    InvalidCluster,
     InvalidRequestException,
     ResourceNotFoundException,
     ValidationException,
 )
-from moto.utilities.utils import CamelToUnderscoresWalker, get_partition
+from moto.utilities.utils import CamelToUnderscoresWalker, get_partition, load_resource
 
 from .utils import (
     EmrSecurityGroupManager,
@@ -37,10 +37,17 @@ class Application(BaseModel):
 
 
 class BootstrapAction(BaseModel):
-    def __init__(self, args: List[str], name: str, script_path: str):
-        self.args = args or []
+    def __init__(self, name: str, script_bootstrap_action: dict[str, Any]):
         self.name = name
-        self.script_path = script_path
+        self.script_bootstrap_action = script_bootstrap_action
+
+    @property
+    def script_path(self) -> Optional[str]:
+        return self.script_bootstrap_action.get("path")
+
+    @property
+    def args(self) -> List[str]:
+        return self.script_bootstrap_action.get("args", [])
 
 
 class Instance(BaseModel):
@@ -285,19 +292,16 @@ class Step(BaseModel):
         self,
         state: str,
         name: str = "",
-        jar: str = "",
-        args: Optional[List[str]] = None,
-        properties: Optional[Dict[str, str]] = None,
+        hadoop_jar_step: Optional[Dict[str, Any]] = None,
         action_on_failure: str = "TERMINATE_CLUSTER",
     ):
         self.id = random_step_id()
-
         self.action_on_failure = action_on_failure
-        self.args = args or []
         self.name = name
-        self.jar = jar
-        self.properties = properties or {}
-
+        self.hadoop_jar_step = hadoop_jar_step or {}
+        self.jar = self.hadoop_jar_step.get("Jar", "")
+        self.args = self.hadoop_jar_step.get("Args", [])
+        self.properties = self.hadoop_jar_step.get("Properties", {})
         self.creation_date_time = utcnow()
         self.end_date_time = None
         self.ready_date_time = None
@@ -308,17 +312,11 @@ class Step(BaseModel):
     def config(self) -> dict[str, Any]:
         config = {
             "ActionOnFailure": self.action_on_failure,
-            "HadoopJarStep": {
-                "Jar": self.jar,
-                "Args": self.args,
-                "Properties": [
-                    {"Key": k, "Value": v} for k, v in self.properties.items()
-                ],
-            },
+            "HadoopJarStep": self.hadoop_jar_step,
             "Name": self.name,
             "Jar": self.jar,
             "Args": self.args,
-            "Properties": self.properties,
+            "Properties": {p["Key"]: p["Value"] for p in self.properties},
         }
         return config
 
@@ -391,6 +389,9 @@ class Cluster(CloudFormationModel):
         security_configuration: Optional[str] = None,
         kerberos_attributes: Optional[Dict[str, str]] = None,
         auto_scaling_role: Optional[str] = None,
+        ebs_root_volume_size: Optional[int] = None,
+        ebs_root_volume_iops: Optional[int] = None,
+        ebs_root_volume_throughput: Optional[int] = None,
     ):
         self.id = cluster_id or random_cluster_id()
         emr_backend.clusters[self.id] = self
@@ -473,13 +474,17 @@ class Cluster(CloudFormationModel):
         self.slave_security_group = instance_attrs.get(
             "emr_managed_slave_security_group"
         )
-        self.termination_protected = instance_attrs.get("termination_protected")
+        self.termination_protected = instance_attrs.get("termination_protected", False)
 
         self.release_label = release_label
         self.requested_ami_version = requested_ami_version
         self.running_ami_version = running_ami_version
         self.custom_ami_id = custom_ami_id
 
+        self.ebs_root_volume_size = ebs_root_volume_size
+        self.ebs_root_volume_iops = ebs_root_volume_iops
+        self.ebs_root_volume_throughput = ebs_root_volume_throughput
+
         self.role = job_flow_role or "EMRJobflowDefault"
         self.service_role = service_role
         self.step_concurrency_level = step_concurrency_level
@@ -517,15 +522,7 @@ class Cluster(CloudFormationModel):
     def bootstrap_action_detail_list(self) -> list[dict[str, Any]]:
         details = []
         for bootstrap_action in self.bootstrap_actions:
-            member = {
-                "BootstrapActionConfig": {
-                    "Name": bootstrap_action.name,
-                    "ScriptBootstrapAction": {
-                        "Args": bootstrap_action.args,
-                        "Path": bootstrap_action.script_path,
-                    },
-                }
-            }
+            member = {"BootstrapActionConfig": bootstrap_action}
             details.append(member)
         return details
 
@@ -544,7 +541,7 @@ class Cluster(CloudFormationModel):
             "KeepJobFlowAliveWhenNoSteps": self.keep_job_flow_alive_when_no_steps,
             "MasterInstanceId": getattr(self, "master_instance_id", None),
             "MasterInstanceType": self.master_instance_type,
-            "MasterPublicDnsName": f"ec2-184-0-0-1.{self.emr_backend.region_name}.compute.amazonaws.com",
+            "MasterPublicDnsName": self.master_public_dns_name,
             "NormalizedInstanceHours": self.normalized_instance_hours,
             "Placement": {"AvailabilityZone": self.availability_zone},
             "SlaveInstanceType": self.slave_instance_type,
@@ -574,7 +571,19 @@ class Cluster(CloudFormationModel):
 
     @property
     def master_public_dns_name(self) -> str:
-        # FIXME: This was hardcoded in the original XML template.
+        if self.master_instance_group_id:
+            master_instance_group = self.emr_backend.instance_groups[
+                self.master_instance_group_id  # type: ignore
+            ]
+
+            for ec2_instance in self.ec2_instances:
+                if ec2_instance.instance_group.id == master_instance_group.id:
+                    dashed_ip, domain = ec2_instance.public_dns_name.split(".", 1)  # type: ignore
+                    return ".".join([dashed_ip, self.emr_backend.region_name, domain])
+
+        # TODO: Moto does not create instances when InstanceGroups is not provided to RunJobFlow operation.
+        #  In fact it should also do so when InstanceCount/InstanceType are provided.
+        #  For now, just return a hardcoded value for such cases.
         return "ec2-184-0-0-1.us-west-1.compute.amazonaws.com"
 
     @property
@@ -830,6 +839,23 @@ class ElasticMapReduceBackend(BaseBackend):
         self.security_configurations: Dict[str, SecurityConfiguration] = {}
         self.block_public_access_configuration: Dict[str, Any] = {}
 
+    @cached_property
+    def _release_labels(self) -> list[str]:
+        """Returns all available release labels in this region"""
+        return load_resource(
+            __name__, f"resources/release-labels-{self.region_name}.json"
+        )
+
+    @cache
+    def _get_instance_type_names(self, release_label: str) -> list[str]:
+        """Returns all instance type names that can be used with this release label"""
+        return load_resource(__name__, f"resources/instance-types-{release_label}.json")
+
+    @cached_property
+    def _instance_types(self) -> dict[str, Any]:
+        """Returns a dictionary of {instance-type-name: instance-type-details}"""
+        return load_resource(__name__, "resources/instance_types.json")
+
     @property
     def ec2_backend(self) -> Any:
         """
@@ -887,8 +913,8 @@ class ElasticMapReduceBackend(BaseBackend):
         self,
         job_flow_ids: Optional[List[str]] = None,
         job_flow_states: Optional[List[str]] = None,
-        created_after: Optional[str] = None,
-        created_before: Optional[str] = None,
+        created_after: Optional[datetime] = None,
+        created_before: Optional[datetime] = None,
     ) -> List[Cluster]:
         clusters = list(self.clusters.values())
 
@@ -900,17 +926,9 @@ class ElasticMapReduceBackend(BaseBackend):
         if job_flow_states:
             clusters = [c for c in clusters if c.state in job_flow_states]
         if created_after:
-            clusters = [
-                c
-                for c in clusters
-                if c.creation_datetime > dtparse(created_after).replace(tzinfo=None)
-            ]
+            clusters = [c for c in clusters if c.creation_datetime > created_after]
         if created_before:
-            clusters = [
-                c
-                for c in clusters
-                if c.creation_datetime < dtparse(created_before).replace(tzinfo=None)
-            ]
+            clusters = [c for c in clusters if c.creation_datetime < created_before]
 
         # Amazon EMR can return a maximum of 512 job flow descriptions
         return sorted(clusters, key=lambda x: x.id)[:512]
@@ -925,7 +943,7 @@ class ElasticMapReduceBackend(BaseBackend):
     def describe_cluster(self, cluster_id: str) -> Cluster:
         if cluster_id in self.clusters:
             return self.clusters[cluster_id]
-        raise ResourceNotFoundException("")
+        raise InvalidCluster(cluster_id)
 
     def get_instance_groups(self, instance_group_ids: List[str]) -> List[InstanceGroup]:
         return [
@@ -950,8 +968,8 @@ class ElasticMapReduceBackend(BaseBackend):
     def list_clusters(
         self,
         cluster_states: Optional[List[str]] = None,
-        created_after: Optional[str] = None,
-        created_before: Optional[str] = None,
+        created_after: Optional[datetime] = None,
+        created_before: Optional[datetime] = None,
         marker: Optional[str] = None,
     ) -> Tuple[List[Cluster], Optional[str]]:
         max_items = 50
@@ -959,17 +977,9 @@ class ElasticMapReduceBackend(BaseBackend):
         if cluster_states:
             clusters = [c for c in clusters if c.state in cluster_states]
         if created_after:
-            clusters = [
-                c
-                for c in clusters
-                if c.creation_datetime > dtparse(created_after).replace(tzinfo=None)
-            ]
+            clusters = [c for c in clusters if c.creation_datetime > created_after]
         if created_before:
-            clusters = [
-                c
-                for c in clusters
-                if c.creation_datetime < dtparse(created_before).replace(tzinfo=None)
-            ]
+            clusters = [c for c in clusters if c.creation_datetime < created_before]
         clusters = sorted(clusters, key=lambda x: x.id)
         start_idx = 0 if marker is None else int(marker)
         marker = (
@@ -1146,15 +1156,15 @@ class ElasticMapReduceBackend(BaseBackend):
 
     def get_security_configuration(self, name: str) -> SecurityConfiguration:
         if name not in self.security_configurations:
-            raise InvalidRequestException(
-                message=f"Security configuration with name '{name}' does not exist."
+            raise ResourceNotFoundException(
+                f"Security configuration with name '{name}' does not exist."
             )
         return self.security_configurations[name]
 
     def delete_security_configuration(self, name: str) -> None:
         if name not in self.security_configurations:
-            raise InvalidRequestException(
-                message=f"Security configuration with name '{name}' does not exist."
+            raise ResourceNotFoundException(
+                f"Security configuration with name '{name}' does not exist."
             )
         del self.security_configurations[name]
 
@@ -1192,5 +1202,22 @@ class ElasticMapReduceBackend(BaseBackend):
         }
         return
 
+    def list_release_labels(self) -> list[str]:
+        """
+        Pagination and Filtering is not yet implemented
+        """
+        return self._release_labels
+
+    def list_supported_instance_types(self, release_label: str) -> list[dict[str, Any]]:
+        """
+        Pagination is not yet implemented
+        """
+        instance_type_names = self._get_instance_type_names(release_label)
+        return [
+            details
+            for name, details in self._instance_types.items()
+            if name in instance_type_names
+        ]
+
 
 emr_backends = BackendDict(ElasticMapReduceBackend, "emr")
