@@ -6,17 +6,15 @@ class KinesisvideoClientError(RESTError):
 
 
 class ResourceNotFoundException(KinesisvideoClientError):
-    def __init__(self):
+    def __init__(self) -> None:
         self.code = 404
-        super(ResourceNotFoundException, self).__init__(
+        super().__init__(
             "ResourceNotFoundException",
             "The requested stream is not found or not active.",
         )
 
 
 class ResourceInUseException(KinesisvideoClientError):
-    def __init__(self, message):
+    def __init__(self, message: str):
         self.code = 400
-        super(ResourceInUseException, self).__init__(
-            "ResourceInUseException", message,
-        )
+        super().__init__("ResourceInUseException", message)
