@@ -53,6 +53,22 @@ class RuleDoesNotExist(SesError):
     code = "RuleDoesNotExist"
 
 
+class CannotDelete(SesError):
+    code = "CannotDelete"
+
+
+class InvalidS3ConfigurationException(SesError):
+    code = "InvalidS3Configuration"
+
+
+class InvalidSnsTopicException(SesError):
+    code = "InvalidSnsTopic"
+
+
+class InvalidLambdaFunctionException(SesError):
+    code = "InvalidLambdaFunction"
+
+
 class MissingRenderingAttributeException(SesError):
     code = "MissingRenderingAttributeException"
 
