@@ -20,7 +20,7 @@ from moto.core.utils import (
     unix_time_millis,
 )
 from moto.moto_api._internal import mock_random as random
-from moto.utilities.utils import md5_hash
+from moto.utilities.utils import get_partition, md5_hash
 
 from .constants import MAXIMUM_VISIBILITY_TIMEOUT
 from .exceptions import (
@@ -45,7 +45,7 @@ if TYPE_CHECKING:
 
 DEFAULT_SENDER_ID = "AIDAIT2UOQQY3AUEKVGXU"
 
-MAXIMUM_MESSAGE_LENGTH = 262144  # 256 KiB
+MAXIMUM_MESSAGE_LENGTH = 1048576  # 1 MB
 
 MAXIMUM_MESSAGE_SIZE_ATTR_LOWER_BOUND = 1024
 MAXIMUM_MESSAGE_SIZE_ATTR_UPPER_BOUND = MAXIMUM_MESSAGE_LENGTH
@@ -278,7 +278,7 @@ class Queue(CloudFormationModel):
 
         now = unix_time()
         self.created_timestamp = now
-        self.queue_arn = f"arn:aws:sqs:{region}:{account_id}:{name}"
+        self.queue_arn = f"arn:{get_partition(region)}:sqs:{region}:{account_id}:{name}"
         self.dead_letter_queue: Optional["Queue"] = None
         self.fifo_queue = False
 
@@ -804,6 +804,7 @@ class SQSBackend(BaseBackend):
         delay_seconds: int,
         deduplication_id: Optional[str] = None,
         group_id: Optional[str] = None,
+        validate_group_id: bool = True,
     ) -> None:
         if queue.fifo_queue:
             if (
@@ -834,18 +835,10 @@ class SQSBackend(BaseBackend):
             msg = f"One or more parameters are invalid. Reason: Message must be shorter than {queue.maximum_message_size} bytes."  # type: ignore
             raise InvalidParameterValue(msg)
 
-        if group_id is None:
-            if queue.fifo_queue:
-                # MessageGroupId is a mandatory parameter for all
-                # messages in a fifo queue
-                raise MissingParameter("MessageGroupId")
-        else:
-            if not queue.fifo_queue:
-                msg = (
-                    f"Value {group_id} for parameter MessageGroupId is invalid. "
-                    "Reason: The request include parameter that is not valid for this queue type."
-                )
-                raise InvalidParameterValue(msg)
+        if group_id is None and queue.fifo_queue:
+            # MessageGroupId is a mandatory parameter for all
+            # messages in a fifo queue
+            raise MissingParameter("MessageGroupId")
 
     def send_message(
         self,
@@ -856,11 +849,17 @@ class SQSBackend(BaseBackend):
         deduplication_id: Optional[str] = None,
         group_id: Optional[str] = None,
         system_attributes: Optional[Dict[str, Any]] = None,
+        validate_group_id: bool = True,
     ) -> Message:
         queue = self.get_queue(queue_name)
 
         self._validate_message(
-            queue, message_body, int(delay_seconds or 0), deduplication_id, group_id
+            queue,
+            message_body=message_body,
+            delay_seconds=int(delay_seconds or 0),
+            deduplication_id=deduplication_id,
+            group_id=group_id,
+            validate_group_id=validate_group_id,
         )
 
         if delay_seconds is not None:
@@ -1155,7 +1154,12 @@ class SQSBackend(BaseBackend):
         return queues
 
     def add_permission(
-        self, queue_name: str, actions: List[str], account_ids: List[str], label: str
+        self,
+        region_name: str,
+        queue_name: str,
+        actions: List[str],
+        account_ids: List[str],
+        label: str,
     ) -> None:
         queue = self.get_queue(queue_name)
 
@@ -1195,7 +1199,10 @@ class SQSBackend(BaseBackend):
                 f"Value {label} for parameter Label is invalid. Reason: Already exists."
             )
 
-        principals = [f"arn:aws:iam::{account_id}:root" for account_id in account_ids]
+        principals = [
+            f"arn:{get_partition(region_name)}:iam::{account_id}:root"
+            for account_id in account_ids
+        ]
         actions = [f"SQS:{action}" for action in actions]
 
         statement = {
