@@ -21,6 +21,8 @@ from moto.utilities.utils import load_resource
 
 from .exceptions import (
     AccessDeniedException,
+    AlreadyExistsException,
+    BaselineDoesNotExistException,
     DocumentAlreadyExists,
     DocumentPermissionLimit,
     DoesNotExistException,
@@ -169,7 +171,7 @@ class ParameterDict(DefaultDict[str, List["Parameter"]]):
         if item.startswith("/aws/reference/secretsmanager/"):
             return self._get_secretsmanager_parameter("/".join(item.split("/")[4:]))
         self._check_loading_status(item)
-        return super().__getitem__(item)
+        return super().__getitem__(self.normalize_name(item))
 
     def __contains__(self, k: str) -> bool:  # type: ignore[override]
         if k and k.startswith("/aws/reference/secretsmanager/"):
@@ -181,7 +183,7 @@ class ParameterDict(DefaultDict[str, List["Parameter"]]):
                     f"An error occurred (ParameterNotFound) when referencing Secrets Manager: Secret {k} not found."
                 )
         self._check_loading_status(k)
-        return super().__contains__(k)
+        return super().__contains__(self.normalize_name(k))
 
     def get_keys_beginning_with(self, path: str, recursive: bool) -> Iterator[str]:
         self._check_loading_status(path)
@@ -192,6 +194,16 @@ class ParameterDict(DefaultDict[str, List["Parameter"]]):
                 continue
             yield param_name
 
+    @staticmethod
+    def normalize_name(name: str) -> str:
+        if not name:
+            return name
+
+        stripped = name.removeprefix("/")
+        if "/" in stripped:
+            return name
+        return stripped
+
 
 PARAMETER_VERSION_LIMIT = 100
 PARAMETER_HISTORY_MAX_RESULTS = 50
@@ -210,7 +222,6 @@ class Parameter(CloudFormationModel):
         last_modified_date: float,
         version: int,
         data_type: str,
-        tags: Optional[List[Dict[str, str]]] = None,
         labels: Optional[List[str]] = None,
         source_result: Optional[str] = None,
         tier: Optional[str] = None,
@@ -225,7 +236,6 @@ class Parameter(CloudFormationModel):
         self.last_modified_date = last_modified_date
         self.version = version
         self.data_type = data_type
-        self.tags = tags or []
         self.labels = labels or []
         self.source_result = source_result
         self.tier = tier
@@ -361,10 +371,13 @@ class Parameter(CloudFormationModel):
         account_id: str,
         region_name: str,
     ) -> None:
-        ssm_backend = ssm_backends[account_id][region_name]
-        properties = cloudformation_json["Properties"]
+        resource = resource_name
 
-        ssm_backend.delete_parameter(properties.get("Name"))
+        ssm_backend = ssm_backends[account_id][region_name]
+        if not resource:
+            properties = cloudformation_json["Properties"]
+            resource = properties.get("Name")
+        ssm_backend.delete_parameter(resource)
 
     @property
     def physical_resource_id(self) -> str:
@@ -1163,6 +1176,23 @@ class FakePatchBaseline:
         return "pb-" + "".join(str(random.choice(chars)) for _ in range(17))
 
 
+class FakePatchGroup:
+    def __init__(self, name: str, region_name: str):
+        self.name = name
+        self.region_name = region_name
+        self._load_latest_baselines()
+        self.associations = self.default_associations
+
+    def _load_latest_baselines(self) -> None:
+        try:
+            latest_patch_baselines = load_resource(
+                __name__, "resources/default_baselines.json"
+            )
+        except FileNotFoundError:
+            latest_patch_baselines = {}
+        self.default_associations = latest_patch_baselines[self.region_name]
+
+
 class SimpleSystemManagerBackend(BaseBackend):
     """
     Moto supports the following default parameters out of the box:
@@ -1188,6 +1218,7 @@ class SimpleSystemManagerBackend(BaseBackend):
 
         self.windows: Dict[str, FakeMaintenanceWindow] = dict()
         self.baselines: Dict[str, FakePatchBaseline] = dict()
+        self.patch_groups: Dict[str, FakePatchGroup] = dict()
         self.ssm_prefix = (
             f"arn:{self.partition}:ssm:{self.region_name}:{self.account_id}:parameter"
         )
@@ -1540,16 +1571,20 @@ class SimpleSystemManagerBackend(BaseBackend):
         )
 
     def delete_parameter(self, name: str) -> Optional[Parameter]:
-        self._resource_tags.get("Parameter", {}).pop(name, None)  # type: ignore
-        return self._parameters.pop(name, None)  # type: ignore
+        normalized_parameter_name = self._parameters.normalize_name(name)
+        self._resource_tags.get("Parameter", {}).pop(normalized_parameter_name, None)  # type: ignore
+        return self._parameters.pop(normalized_parameter_name, None)  # type: ignore
 
     def delete_parameters(self, names: List[str]) -> List[str]:
         result = []
         for name in names:
             try:
-                del self._parameters[name]
+                normalized_parameter_name = self._parameters.normalize_name(name)
+                del self._parameters[normalized_parameter_name]
                 result.append(name)
-                self._resource_tags.get("Parameter", {}).pop(name, None)  # type: ignore
+                self._resource_tags.get("Parameter", {}).pop(
+                    normalized_parameter_name, None
+                )  # type: ignore
             except KeyError:
                 pass
         return result
@@ -1850,6 +1885,7 @@ class SimpleSystemManagerBackend(BaseBackend):
         self, parameter: Parameter, filters: Optional[List[Dict[str, Any]]] = None
     ) -> bool:
         """Return True if the given parameter matches all the filters"""
+        parameter_tags = self.list_tags_for_resource("Parameter", parameter.name)
         for filter_obj in filters or []:
             key = filter_obj["Key"]
             values = filter_obj.get("Values", [])
@@ -1879,7 +1915,11 @@ class SimpleSystemManagerBackend(BaseBackend):
                 else:
                     continue
             elif key.startswith("tag:"):
-                what = [tag["Value"] for tag in parameter.tags if tag["Key"] == key[4:]]
+                what = [
+                    tag_value
+                    for tag_key, tag_value in parameter_tags.items()
+                    if tag_key == key[4:]
+                ]
 
             if what is None or what == []:
                 return False
@@ -2132,7 +2172,6 @@ class SimpleSystemManagerBackend(BaseBackend):
                 else previous_parameter.allowed_pattern
             )
             keyid = keyid if keyid is not None else previous_parameter.keyid
-            tags = tags if tags is not None else previous_parameter.tags
             data_type = (
                 data_type if data_type is not None else previous_parameter.data_type
             )
@@ -2150,7 +2189,6 @@ class SimpleSystemManagerBackend(BaseBackend):
             keyid=keyid,
             last_modified_date=last_modified_date,
             version=version,
-            tags=tags or [],
             data_type=data_type,
             tier=tier,
             policies=policies,
@@ -2166,14 +2204,14 @@ class SimpleSystemManagerBackend(BaseBackend):
     def add_tags_to_resource(
         self, resource_type: str, resource_id: str, tags: Dict[str, str]
     ) -> None:
-        self._validate_resource_type_and_id(resource_type, resource_id)
+        resource_id = self._validate_resource_type_and_id(resource_type, resource_id)
         for key, value in tags.items():
             self._resource_tags[resource_type][resource_id][key] = value
 
     def remove_tags_from_resource(
         self, resource_type: str, resource_id: str, keys: List[str]
     ) -> None:
-        self._validate_resource_type_and_id(resource_type, resource_id)
+        resource_id = self._validate_resource_type_and_id(resource_type, resource_id)
         tags = self._resource_tags[resource_type][resource_id]
         for key in keys:
             if key in tags:
@@ -2182,22 +2220,20 @@ class SimpleSystemManagerBackend(BaseBackend):
     def list_tags_for_resource(
         self, resource_type: str, resource_id: str
     ) -> Dict[str, str]:
-        self._validate_resource_type_and_id(resource_type, resource_id)
+        resource_id = self._validate_resource_type_and_id(resource_type, resource_id)
         return self._resource_tags[resource_type][resource_id]
 
     def _validate_resource_type_and_id(
         self, resource_type: str, resource_id: str
-    ) -> None:
+    ) -> str:
         if resource_type == "Parameter":
-            if resource_id not in self._parameters:
+            if not (parameter := self.get_parameter(resource_id)):
                 raise InvalidResourceId()
             else:
-                return
+                return parameter.name
         elif resource_type == "Document":
             if resource_id not in self._documents:
                 raise InvalidResourceId()
-            else:
-                return
         elif resource_type == "MaintenanceWindow":
             if resource_id not in self.windows:
                 raise InvalidResourceId()
@@ -2213,6 +2249,8 @@ class SimpleSystemManagerBackend(BaseBackend):
         else:
             raise InvalidResourceId()
 
+        return resource_id
+
     def send_command(
         self,
         comment: str,
@@ -2517,5 +2555,44 @@ class SimpleSystemManagerBackend(BaseBackend):
         window = self.get_maintenance_window(window_id)
         del window.tasks[window_task_id]
 
+    def register_patch_baseline_for_patch_group(
+        self, baseline_id: str, patch_group: str
+    ) -> Tuple[str, str]:
+        """register a patch group in ssm backend"""
+        if baseline_id not in self.baselines.keys():
+            raise DoesNotExistException(baseline_id)
+        baseline_os = self.baselines[baseline_id].operating_system
+        if patch_group in self.patch_groups.keys():
+            if self.patch_groups[patch_group].associations[baseline_os] != baseline_id:
+                raise AlreadyExistsException(baseline_os)
+            self.patch_groups[patch_group].associations[baseline_os] = baseline_id
+        else:
+            fake_patch_group = FakePatchGroup(patch_group, self.region_name)
+            fake_patch_group.associations[baseline_os] = baseline_id
+            self.patch_groups[patch_group] = fake_patch_group
+        return baseline_id, patch_group
+
+    def get_patch_baseline_for_patch_group(
+        self, patch_group: str, operating_system: str
+    ) -> Tuple[str, str, str]:
+        """get baselineid for patch group for operating system"""
+        if patch_group not in self.patch_groups.keys():
+            fake_patch_group = FakePatchGroup("Fake", self.region_name)
+            baseline_id = fake_patch_group.associations[operating_system]
+        else:
+            baseline_id = self.patch_groups[patch_group].associations[operating_system]
+        return baseline_id, patch_group, operating_system
+
+    def deregister_patch_baseline_for_patch_group(
+        self, baseline_id: str, patch_group: str
+    ) -> Tuple[str, str]:
+        """deregister a patch baseline for os on patch group, set default"""
+        if patch_group in self.patch_groups.keys():
+            if baseline_id not in self.baselines.keys():
+                raise BaselineDoesNotExistException
+            baseline_os = self.baselines[baseline_id].operating_system
+            self.patch_groups[patch_group].associations[baseline_os] = baseline_id
+        return baseline_id, patch_group
+
 
 ssm_backends = BackendDict(SimpleSystemManagerBackend, "ssm")
