@@ -7,7 +7,7 @@ from moto.stepfunctions.parser.asl.component.state.choice.comparison.operator.op
     Operator,
 )
 from moto.stepfunctions.parser.asl.eval.environment import Environment
-from moto.stepfunctions.parser.asl.utils.json_path import JSONPathUtils
+from moto.stepfunctions.parser.asl.utils.json_path import extract_json
 
 
 class BooleanEquals(Operator):
@@ -34,7 +34,7 @@ class BooleanEqualsPath(Operator):
         variable = env.stack.pop()
 
         inp = env.stack[-1]
-        comp_value: bool = JSONPathUtils.extract_json(value, inp)
+        comp_value: bool = extract_json(value, inp)
         if not isinstance(comp_value, bool):
             raise TypeError(
                 f"Expected type bool, but got '{comp_value}' from path '{value}'."
