@@ -1,4 +1,4 @@
-from typing import Any
+from typing import Any, Final
 
 from moto.stepfunctions.parser.asl.component.state.exec.state_map.item_reader.reader_config.max_items_decl import (
     MaxItemsDecl,
@@ -7,7 +7,7 @@ from moto.stepfunctions.parser.asl.parse.typed_props import TypedProps
 
 
 class ReaderConfigProps(TypedProps):
-    _UNIQUE_SUB_INSTANCES = {MaxItemsDecl}
+    _UNIQUE_SUB_INSTANCES: Final[set[type]] = {MaxItemsDecl}
     name: str
 
     def add(self, instance: Any) -> None:
